@@ -9,7 +9,7 @@ def mq_init(base_url):
     else:
         fp = open(file_path,'a+')
         fp.writelines(['\n'*4,'class DB_django_task_mq(models.Model):','\n    topic = models.CharField(max_length=100,null=True,blank=True,default="")',
-                       '\n    message = models.TextField(default="{}")','\n    status = models.BooleanField(default=True)','\n    task_id = models.CharField(max_length=100,null=True,blank=True,default="")','\n    def __str__(self):','\n        return self.topic'])
+                       '\n    message = models.TextField(default="{}")','\n    status = models.BooleanField(default=True)','\n    def __str__(self):','\n        return self.topic'])
         fp.close()
         file_path = os.path.join(base_url,'admin.py')
         fp = open(file_path,'a+')
@@ -30,7 +30,7 @@ def mq_consumer(DB_django_task_mq,fun,topic):
             mq.status = False
             mq.save()
             try:
-                fun(mq.message)
+                fun(mq)
             except Exception as e:
                 print('[ERROR]:',e)
             finally:
